@@ -38,21 +38,17 @@ along with Highlight.  If not, see <http://www.gnu.org/licenses/>.
 #include "syntaxreader.h"
 #include "lspprofile.h"
 
-#define MAX_LINE__WIDTH       80
-
-using namespace std;
-
 void HLCmdLineApp::printVersionInfo(bool quietMode)
 {
     if (quietMode) {
-        cout << highlight::Info::getVersion() << "\n";
+        std::cout << highlight::Info::getVersion() << "\n";
     } else {
-        cout << "\n highlight version "
+        std::cout << "\n highlight version "
             << highlight::Info::getVersion()
             << "\n Copyright (C) 2002-2023 Andre Simon <a dot simon at mailbox.org>"
             << "\n\n Argparser class"
             << "\n Copyright (C) 2006-2008 Antonio Diaz Diaz <ant_diaz at teleline.es>"
-            << "\n\n Artistic Style Classes (3.2)"
+            << "\n\n Artistic Style Classes (3.3)"
             << "\n Copyright (C) 1998-2023 The Artistic Style Authors"
             << "\n\n Diluculum Lua wrapper (1.0)"
             << "\n Copyright (C) 2005-2013 by Leandro Motta Barros"
@@ -70,43 +66,43 @@ void HLCmdLineApp::printVersionInfo(bool quietMode)
 
 void HLCmdLineApp::printBadInstallationInfo()
 {
-    cerr << "highlight: Data directory not found ("<<DataDir::LSB_DATA_DIR<<")."
+    std::cerr << "highlight: Data directory not found ("<<DataDir::LSB_DATA_DIR<<")."
          " Bad installation or wrong "<< OPT_DATADIR << " parameter."
          << "\n\nCopy the highlight files into one of the directories listed "
          << "in INSTALL.\nYou may also set the data directory with "
          << OPT_DATADIR << ".\n";
 }
 
-int HLCmdLineApp::printInstalledFiles(const string& where, const string& wildcard, const string& kind, const string& option, const string& categoryFilterList)
+int HLCmdLineApp::printInstalledFiles(const std::string& where, const std::string& wildcard, const std::string& kind, const std::string& option, const std::string& categoryFilterList)
 {
-    vector <string> filePaths;
-    string searchDir = where + wildcard;
+    std::vector <string> filePaths;
+    std::string searchDir = where + wildcard;
 
     bool directoryOK = Platform::getDirectoryEntries ( filePaths, searchDir, true );
     if ( !directoryOK ) {
-        cerr << "highlight: Could not access directory "
+        std::cerr << "highlight: Could not access directory "
              <<  searchDir
              << ", aborted.\n";
         return EXIT_FAILURE;
     }
 
-    sort ( filePaths.begin(), filePaths.end() );
-    string suffix, desc;
+    std::sort ( filePaths.begin(), filePaths.end() );
+    std::string suffix, desc;
     Diluculum::LuaValueMap categoryMap;
-    cout << "\nInstalled " << kind << "s";
+    std::cout << "\nInstalled " << kind << "s";
 
     if (categoryFilterList.size())
-        cout << " matching \""<<categoryFilterList<<"\"";
+        std::cout << " matching \""<<categoryFilterList<<"\"";
 
-    cout << " (located in " << where << "):\n\n";
+    std::cout << " (located in " << where << "):\n\n";
     int matchedFileCnt=0;
     std::set<string> categoryNames;
     std::set<string> categoryFilters;
 
-    istringstream valueStream;
-    string catFilter;
-    valueStream.str ( StringTools::change_case ( categoryFilterList,StringTools::CASE_LOWER ) );
-    while ( getline ( valueStream, catFilter, ';' ) ) {
+    std::istringstream valueStream;
+    std::string catFilter;
+    valueStream.str ( StringTools::change_case ( categoryFilterList, StringTools::CASE_LOWER ) );
+    while ( std::getline ( valueStream, catFilter, ';' ) ) {
         categoryFilters.insert ( catFilter );
     }
 
@@ -139,41 +135,41 @@ int HLCmdLineApp::printInstalledFiles(const string& where, const string& wildcar
 
             matchedFileCnt++;
             if (kind=="langDef") {
-                cout << setw ( 30 ) <<setiosflags ( ios::left ) <<desc<<": "<<suffix;
+                std::cout << setw ( 30 ) <<setiosflags ( ios::left ) <<desc<<": "<<suffix;
 
                 int extCnt=0;
                 for (StringMap::iterator it=dataDir.assocByExtension.begin(); it!=dataDir.assocByExtension.end(); it++) {
                     if (it->second==suffix ) {
-                        cout << ((++extCnt==1)?" ( ":" ")<<it->first;
+                        std::cout << ((++extCnt==1)?" ( ":" ")<<it->first;
                     }
                 }
-                cout << ((extCnt)?" )":"");
+                std::cout << ((extCnt)?" )":"");
             } else {
-                cout << setw ( 30 ) <<setiosflags ( ios::left ) <<suffix<<": "<<desc;
+                std::cout << setw ( 30 ) <<setiosflags ( ios::left ) <<suffix<<": "<<desc;
 
             }
-            cout << endl;
+            std::cout << endl;
         } catch (std::runtime_error &error) {
-            cout << "Failed to read '" << path<< "': " << error.what() << endl;
+            std::cout << "Failed to read '" << path << "': " << error.what() << endl;
         }
     }
 
     if (!matchedFileCnt) {
-        cout <<"No files found." << endl;
+        std::cout <<"No files found." << endl;
     } else {
 
         if (!categoryFilters.size()){
-            cout << "\nFound "<<kind<<" categories:\n\n";
+            std::cout << "\nFound "<<kind<<" categories:\n\n";
             for (std::set<string>::iterator it=categoryNames.begin(); it!=categoryNames.end(); ++it)
                 std::cout << *it<< ' ';
-            cout << "\n";
+            std::cout << "\n";
         }
 
-        cout <<"\nUse name of the desired "<<kind
+        std::cout <<"\nUse name of the desired "<<kind
             << " with --" << option << ". Filter categories with --list-cat." << endl;
 
         if (kind=="theme") {
-            cout <<"\nAdd base16/ prefix to apply a Base16 theme." << endl;
+            std::cout <<"\nAdd base16/ prefix to apply a Base16 theme." << endl;
         }
 
         printConfigInfo();
@@ -247,17 +243,17 @@ void HLCmdLineApp::printDebugInfo ( const highlight::SyntaxReader *lang,
 
 void HLCmdLineApp::printConfigInfo ( )
 {
-    cout << "\nConfig file search directories:\n";
+    std::cout << "\nConfig file search directories:\n";
     dataDir.printConfigPaths();
-    cout << "\nFiletype config file:\n"<<dataDir.getFiletypesConfPath ( "filetypes" ) <<"\n";
-    cout << endl;
+    std::cout << "\nFiletype config file:\n"<<dataDir.getFiletypesConfPath ( "filetypes" ) <<"\n";
+    std::cout << endl;
 #ifdef HL_DATA_DIR
-    cout << "Compiler directive HL_DATA_DIR = " <<HL_DATA_DIR<< "\n";
+    std::cout << "Compiler directive HL_DATA_DIR = " <<HL_DATA_DIR<< "\n";
 #endif
 #ifdef HL_CONFIG_DIR
-    cout << "Compiler directive HL_CONFIG_DIR = " <<HL_CONFIG_DIR<< "\n";
+    std::cout << "Compiler directive HL_CONFIG_DIR = " <<HL_CONFIG_DIR<< "\n";
 #endif
-    cout << endl;
+    std::cout << endl;
 }
 
 int HLCmdLineApp::getNumDigits ( int i )
@@ -275,20 +271,20 @@ void HLCmdLineApp::printProgressBar ( int total, int count )
     if ( !total ) return;
     int p=100*count / total;
     int numProgressItems=p/10;
-    cout << "\r[";
+    std::cout << "\r[";
     for ( int i=0; i<10; i++ ) {
-        cout << ( ( i<numProgressItems ) ?"#":" " );
+        std::cout << ( ( i<numProgressItems ) ?"#":" " );
     }
-    cout<< "] " <<setw ( 3 ) <<p<<"%, "<<count << " / " << total << "  " <<flush;
+    std::cout<< "] " <<setw ( 3 ) <<p<<"%, "<<count << " / " << total << "  " <<flush;
     if ( p==100 ) {
-        cout << endl;
+        std::cout << endl;
     }
 }
 
 void HLCmdLineApp::printCurrentAction ( const string&outfilePath,
                                         int total, int count, int countWidth )
 {
-    cout << "Writing file "
+    std::cout << "Writing file "
          << setw ( countWidth ) << count
          << " of "
          << total
@@ -336,7 +332,80 @@ vector <string> HLCmdLineApp::collectPluginPaths(const vector<string>& plugins)
     }
     return absolutePaths;
 }
+bool HLCmdLineApp::serviceModeCheck(CmdLineOptions &options, highlight::CodeGenerator* generator, string &suffix, unsigned int &curFileIndex){
+    if (! options.runServiceMode())
+        return false;
 
+    cerr << flush;
+    if (! service_mode_tag.empty())
+        std::cout << service_mode_tag << endl;
+
+    std::cout << flush;
+
+    if (cin.eof())
+        return false;
+
+    curFileIndex = 0; //stay on our stdin
+
+    if (cin.peek() == generator->getAdditionalEOFChar()) {
+        cin.get(); //eof char
+        if (cin.peek() == '\n') //this should always be true if they properly give input but if they separated files with just EOF marker we won't chomp their first char
+            cin.get(); //eol after it
+    }
+
+    string modeChanges;
+    getline(cin, modeChanges);
+    if (modeChanges == "exit"){
+        cin.setstate(std::ios_base::eofbit);
+        return false;
+    }
+
+    istringstream modesStream(modeChanges);
+    string modeChange;
+    string modeRes;
+    string modeKey;
+    string modeVal;
+
+    while (getline(modesStream, modeChange, ';')) {
+
+        istringstream modeStream(modeChange);
+
+        getline(modeStream, modeKey, '=');
+        getline(modeStream, modeVal);
+
+        if (modeKey == "syntax") {
+            if (modeVal.find(".") != string::npos)
+                suffix = dataDir.guessFileType(dataDir.getFileSuffix(modeVal), modeVal);
+            else
+                suffix = modeVal;
+            modeRes += "Syntax: " + suffix + " ";
+        } else if (modeKey == "line-length"){
+            int lineLength=0;
+
+            StringTools::str2num<int> ( lineLength, modeVal, std::dec );
+
+            options.setLineLength(lineLength);
+            modeRes += "LineLen: " + modeVal + " ";
+
+            generator->setPreformatting(options.getWrappingStyle(),
+                (generator->getPrintLineNumbers()) ?
+                options.getLineLength() - options.getNumberWidth() : options.getLineLength(),
+                options.getNumberSpaces());
+        } else if (modeKey == "eof") {
+            unsigned char eof = (unsigned char)modeVal[0];
+            generator->setAdditionalEOFChar(eof);
+            modeRes += "eof char val: " + std::to_string(eof) + " ";
+        } else if (modeKey == "tag") {
+            service_mode_tag = modeVal;
+            modeRes += "Tag: " + service_mode_tag + " ";
+        } else if (modeKey.length() )
+            cerr << "Invalid service mode key change of: " << modeKey << " ignoring." << endl;
+    }
+    if (options.verbosityLevel())
+        cerr << "Updated Items: " << modeRes << endl;
+
+    return true;
+}
 int HLCmdLineApp::run ( const int argc, const char*argv[] )
 {
     CmdLineOptions options ( argc, argv );
@@ -362,12 +431,25 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
     }
 
 #ifdef _WIN32
+
+// available in recent Windows SDK
+#ifndef ENABLE_VIRTUAL_TERMINAL_PROCESSING
+#define ENABLE_VIRTUAL_TERMINAL_PROCESSING 0x0004
+#endif
+
     //https://docs.microsoft.com/en-us/windows/console/setconsolemode
     HANDLE hOutput = GetStdHandle(STD_OUTPUT_HANDLE);
     DWORD dwMode;
     GetConsoleMode(hOutput, &dwMode);
-    dwMode |= ENABLE_PROCESSED_OUTPUT | 0x200 ;
+    dwMode |= ENABLE_PROCESSED_OUTPUT | ENABLE_VIRTUAL_TERMINAL_PROCESSING;
     SetConsoleMode(hOutput, dwMode);
+    if ( options.disableEcho() ) {
+        HANDLE hConsole = { GetStdHandle(STD_INPUT_HANDLE) };
+        DWORD consoleMode{};
+        GetConsoleMode(hConsole, &consoleMode);
+        consoleMode &= ~ENABLE_ECHO_INPUT;
+        SetConsoleMode(hConsole, consoleMode);
+    }
 #endif
 
     //call before printInstalledLanguages!
@@ -439,7 +521,7 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
             string langDefPath (options.getAbsLangPath().empty() ? dataDir.getLangPath ( resolvedSuffix +".lang") : options.getAbsLangPath());
 
             if (generator->loadLanguage( langDefPath ) == highlight::LOAD_OK) {
-                cout << "highlight: This syntax is supported\n";
+                std::cout << "highlight: This syntax is supported\n";
                 return EXIT_SUCCESS;
             } else {
                 cerr << "highlight: This syntax is not supported\n";
@@ -582,7 +664,8 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
 
     generator->setFilesCnt(fileCount);
 
-    while ( i < fileCount && !initError ) {
+    while ( (serviceModeCheck(options, generator.get(), suffix, i) || i < fileCount) && !initError ) {
+        std::cout.flush();
 
         if ( Platform::fileSize(inFileList[i]) > options.getMaxFileSize() ) {
 
@@ -605,8 +688,10 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
             }
         }
 
-        if ( !options.syntaxGiven() ) { // determine file type for each file
-            suffix = dataDir.guessFileType ( dataDir.getFileSuffix ( inFileList[i] ), inFileList[i] );
+        if (!options.runServiceMode()) {
+            if (suffix.empty() || !options.syntaxGiven() ) { // determine file type for each file
+                suffix = dataDir.guessFileType ( dataDir.getFileSuffix ( inFileList[i] ), inFileList[i] );
+            }
         }
 
         if ( suffix.empty()  && options.forceOutput()) suffix=options.getFallbackSyntax(); //avoid segfault
@@ -819,7 +904,7 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
             } else {
                 twoPassMode=true;
                 if ( !options.quietMode() &&  !options.forceStdout() ) {
-                    cout << "Enabling two-pass mode using "<<twoPassOutFile<<"\n";
+                    std::cout << "Enabling two-pass mode using "<<twoPassOutFile<<"\n";
                 }
                 //start over, add plug-in to list in next iteration
                 usedFileNames.clear();
